<?php
	add_action( 'init', 'build_taxonomies', 0 );
	 
	function build_taxonomies() {
	    register_taxonomy( 'portfolio-categories', 'portfolio', array( 'hierarchical' => true, 'label' => 'Portfolio Categories', 'query_var' => true, 'rewrite' => true ) ); //This function adds or overwrites a taxonomy. It takes in a name, an object name that it affects, and an array of parameters. It does not return anything.
	}

	//Creating a function to create our CPT
	function register_cpt_portfolio() {

		// Set UI labels for Custom Post Type
	    $labels = array( 
	        'name' => __( 'Portfolio Items', 'portfolio' ), //This is the (probably plural) name for our new post type
	        'singular_name' => __( 'Portfolio Item', 'portfolio' ), //How you’d refer to this in the singular
	        'add_new' => __( 'Add  Portfolio Item', 'portfolio' ), //The add new text
	        'add_new_item' => __( 'Add New Portfolio Item', 'portfolio' ), //The add new item text
	        'edit_item' => __( 'Edit Portfolio Item', 'portfolio' ), //The edit item text
	        'new_item' => __( 'New Portfolio Item', 'portfolio' ), //The add new item text
	        'view_item' => __( 'View Portfolio Item', 'portfolio' ), //The view item text
	        'search_items' => __( 'Search Portfolio Items', 'portfolio' ), //The search items text
	        'not_found' => __( 'No portfolio items found', 'portfolio' ), //The not found text
	        'not_found_in_trash' => __( 'No portfolio items found in Trash', 'portfolio' ), //The not found in trash text
	        'parent_item_colon' => __( 'Parent Portfolio Item:', 'portfolio' ), //The parent text
	        'menu_name' => __( 'Portfolio', 'portfolio_thumbnail' ), //This is the name to give menu items.
	    );

	    // Set other options for Custom Post Type
	    $args = array( 
	        'labels' => $labels, //An array of labels for this post type. By default, post labels are used for non-hierarchical post types and page labels for hierarchical ones.
	        'hierarchical' => true, //Whether the post type is hierarchical (e.g. page). Allows Parent to be specified. The 'supports' parameter should contain 'page-attributes' to show the parent select box on the editor page.
	        'description' => 'Section where portfolio items are added', //A short descriptive summary of what the post type is.
	        'supports' => array( 'title', 'thumbnail', 'comments', 'post-formats'), //Features this CPT supports in Post Editor
	        'taxonomies' => array( 'Project Categories'), //An array of registered taxonomies like category or post_tag that will be used with this post type.
	        'public' => true, //Controls how the type is visible to authors (show_in_nav_menus, show_ui) and readers (exclude_from_search, publicly_queryable).
	        'menu_icon' => 'dashicons-desktop', //The url to the icon to be used for this menu or the name of the icon from the iconfont
	        'show_ui' => true, //Whether to generate a default UI for managing this post type in the admin.
	        'show_in_menu' => true, //Where to show the post type in the admin menu. show_ui must be true.
	        'show_in_nav_menus' => false, //Whether post_type is available for selection in navigation menus.
	        'publicly_queryable' => true, //Whether queries can be performed on the front end as part of parse_request().
	        'exclude_from_search' => false, //Whether to exclude posts with this post type from front end search results.
	        'has_archive' => true, //Enables post type archives. Will use $post_type as archive slug by default.
	        'query_var' => true, //Sets the query_var key for this post type.
	        'can_export' => true, //Can this post_type be exported.
	        'rewrite' => true, //Triggers the handling of rewrites for this post type. To prevent rewrites, set to false.
	        'capability_type' => 'post' //The string to use to build the read, edit, and delete capabilities. May be passed as an array to allow for alternative plurals when using this argument as a base to construct the capabilities, e.g. array('story', 'stories') the first array element will be used for the singular capabilities and the second array element for the plural capabilities, this is instead of the auto generated version if no array is given which would be "storys". The 'capability_type' parameter is used as a base to construct capabilities unless they are explicitly set with the 'capabilities' parameter. It seems that `map_meta_cap` needs to be set to true, to make this work.
	    );

	    register_post_type( 'portfolio', $args );
	    flush_rewrite_rules(); //If registering a post type inside of a plugin, call flush_rewrite_rules() in your activation and deactivation hook (see Flushing Rewrite on Activation below). If flush_rewrite_rules() is not used, then you will have to manually go to Settings > Permalinks and refresh your permalink structure before your custom post type will show the correct structure.
	}
add_action( 'init', 'register_cpt_portfolio' );
?>