<?php
// Filter post content with allowed HTML tags and attributes intact
function kbv_sanitize_text( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}

// Rejects URLs that do not have one of the provided whitelisted protocols (defaulting to http, https, ftp, ftps, mailto, news, irc, gopher, nntp, feed, and telnet), eliminates invalid characters, and removes dangerous characters
function kbv_sanitize_url( $input ) {
    return esc_url( $input );
}

// Makes sure the output value is a integer
function kbv_sanitize_integer( $input ) {
    if( is_numeric( $input ) ) {
        return intval( $input );
    }
}

function kbv_sanitize_color( $input ) {
	if ( '' === $input )
		return '';

	// 3 or 6 hex digits, or the empty string.
	if ( preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $input ) )
		return $input;

	return null;
}

function kbv_customize_options_register( $wp_customize ) {

// Array that lists Google fonts available. Extra fonts can be added to array.
$kbv_custom_fonts = array(
			        'Abel' => 'Abel',
			        'Anton' => 'Anton',
			        'Arimo' => 'Arimo',
			        'Arvo' => 'Arvo',
			        'Bitter' => 'Bitter',
			        'Cabin' => 'Cabin',
			        'Cantarell' => 'Cantarell',
			        'CantataOne' => 'CantataOne',
			        'Changa+One' => 'Changa One',
			        'Comfortaa' => 'Comfortaa',
			        'Dosis' => 'Dosis',
			        'Droid+Sans' => 'Droid Sans',
			        'Droid+Serif' => 'Droid Serif',
			        'Economica' => 'Economica',
			        'Francois+One' => 'Francois One',
			        'Halant' => 'Halant',
			        'Istok+Web' => 'Istok Web',
			        'Josefin+Sans' => 'Josefin Sans',
			        'Kreon' => 'Kreon',
			        'Lato' => 'Lato',
			        'Lobster' => 'Lobster',
			        'Lora' => 'Lora',
			        'Maven+Pro' => 'Maven Pro',
			        'Merriweather' => 'Merriweather',
			        'Montserrat' => 'Montserrat',
			        'Nobile' => 'Nobile',
			        'Noto+Sans' => 'Noto Sans',
			        'Nunito' => 'Nunito',
			        'Open+Sans' => 'Open Sans',
			        'Open+Sans+Condensed' => 'Open Sans Condensed',
			        'Oswald' => 'Oswald',
			        'Oxygen' => 'Oxygen',
			        'Pacifico' => 'Pacifico',
			        'Play' => 'Play',
			        'PT+Sans' => 'PT Sans',
			        'PT+Sans+Narrow' => 'PT Sans Narrow',
			        'PT+Serif' => 'PT Serif',
			        'Questrial' => 'Questrial',
			        'Raleway' => 'Raleway',
			        'Roboto' => 'Roboto',
			        'Roboto+Condensed' => 'Roboto Condensed',
			        'Rokkitt' => 'Rokkitt',
			        'Signika' => 'Signika',
			        'Source+Sans+Pro' => 'Source Sans Pro',
			        'Ubuntu' => 'Ubuntu',
			        'Ubuntu+Condensed' => 'Ubuntu Condensed',
			        'Unkempt' => 'Unkempt',
			        'Vollkorn' => 'Vollkorn',
			        'Yanone+Kaffeesatz' => 'Yanone Kaffeesatz'
);

// Array that lists font sizes available. Extra sizes can be added to array.
$kbv_font_sizes = array(
					'8' => '8px',
					'10' => '10px',
					'12' => '12px',
			        '14' => '14px',
			        '16' => '16px',
			        '18' => '18px',
			        '20' => '20px',
			        '22' => '22px',
			        '24' => '24px',
			        '26' => '26px',
			        '28' => '28px',
			        '30' => '30px',
			        '32' => '32px',
			        '34' => '34px',
			        '36' => '36px',
			        '38' => '38px',
			        '40' => '40px',
			        '42' => '42px',
			        '44' => '44px',
			        '46' => '46px',
			        '48' => '48px',
			        '50' => '50px',
			        '52' => '52px',
			        '54' => '54px',
			        '56' => '56px',
			        '58' => '58px',
			        '60' => '60px',
			        '62' => '62px',
			        '64' => '64px',
			        '66' => '66px',
			        '68' => '68px',
			        '70' => '70px',
			        '72' => '72px',
			        '74' => '74px',
			        '76' => '76px',
			        '78' => '78px',
			        '80' => '80px'
);

/*------------------------------------*\

	GENERAL SETTINGS

\*------------------------------------*/
	
	//Adds a new section to the Theme Customization admin screen.
    $wp_customize->add_section( 'kbv_general_section' , array(
    	'title'      => __( 'General', 'Ilander' ), //The visible name of a controller section.
    	'priority'   => 140, //This controls the order in which this section appears in the Theme Customizer sidebar.
    ));

		//Upload Favicon Image
		$wp_customize->add_setting( 'kbv_favicon_upload' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control(
		       new WP_Customize_Image_Control( $wp_customize, 'kbv_favicon_upload', array(
		               'label'      => __( 'Upload a favicon', 'Ilander' ),
		               'section'    => 'kbv_general_section',
		               'settings'   => 'kbv_favicon_upload',
		               'priority'   => 1, //This controls the order in which this control appears in the Theme Customizer sidebar.
		 )));


		//Upload Logo Image
		$wp_customize->add_setting( 'kbv_logo_upload' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control(
		       new WP_Customize_Image_Control( $wp_customize, 'kbv_logo_upload', array(
		               'label'      => __( 'Upload a logo', 'Ilander' ),
		               'section'    => 'kbv_general_section',
		               'settings'   => 'kbv_logo_upload',
		               'priority'   => 5, //This controls the order in which this control appears in the Theme Customizer sidebar.
		 )));



		//Width of main section if not set to "full"
		$wp_customize->add_setting( 'kbv_section_width' , array(
	    	'default'     => '1100',
	    	'sanitize_callback' => 'kbv_sanitize_integer',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_section_width', array(
		            'label'          => __( 'Width of content container', 'Ilander' ),
		            'section'        => 'kbv_general_section',
		            'settings'       => 'kbv_section_width',
		            'priority'   => 10, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));

/*------------------------------------*\

	END GENERAL SETTINGS

\*------------------------------------*/


/*------------------------------------*\

	SKIN SETTINGS

\*------------------------------------*/
	//Adds a new section to the Theme Customization admin screen.
    $wp_customize->add_section( 'kbv_skin_section' , array(
    	'title'      => __( 'Skin', 'Ilander' ), //The visible name of a controller section.
    	'priority'   => 142, //This controls the order in which this section appears in the Theme Customizer sidebar.
    ));
    	//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_bg_color' , array(
	    	'default'     => '#f8f8f8',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_bg_color', array(
		    	'label'        => __( 'Background Color', 'Ilander' ),
		    	'section'    => 'kbv_skin_section',
		    	'settings'   => 'kbv_bg_color',
		    	'priority'   => 1, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_main_color' , array(
	    	'default'     => '#212121',
	    	'sanitize_callback' => 'kbv_sanitize_color', 
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_main_color', array(
		    	'label'        => __( 'Main Color', 'Ilander' ),
		    	'section'    => 'kbv_skin_section',
		    	'settings'   => 'kbv_main_color',
		    	'priority'   => 5, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_accent1_color' , array(
	    	'default'     => '#49ccc7',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_accent1_color', array(
		    	'label'        => __( 'Accent Color 1', 'Ilander' ),
		    	'section'    => 'kbv_skin_section',
		    	'settings'   => 'kbv_accent1_color',
		    	 'priority'   => 10, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_accent2_color' , array(
	    	'default'     => '#ff6e30',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_accent2_color', array(
		    	'label'        => __( 'Accent Color 2', 'Ilander' ),
		    	'section'    => 'kbv_skin_section',
		    	'settings'   => 'kbv_accent2_color',
		    	'priority'   => 15, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_accent3_color' , array(
	    	'default'     => '#ffc231',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_accent3_color', array(
		    	'label'        => __( 'Accent Color 3', 'Ilander' ),
		    	'section'    => 'kbv_skin_section',
		    	'settings'   => 'kbv_accent3_color',
		    	'priority'   => 20,
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_accent4_color' , array(
	    	'default'     => '#6dd6b6',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_accent4_color', array(
		    	'label'        => __( 'Accent Color 4', 'Ilander' ),
		    	'section'    => 'kbv_skin_section',
		    	'settings'   => 'kbv_accent4_color',
		    	'priority'   => 25, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_border_color' , array(
	    	'default'     => '#dfdfdf',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_border_color', array(
		    	'label'        => __( 'Border and Break Colors', 'Ilander' ),
		    	'section'    => 'kbv_skin_section',
		    	'settings'   => 'kbv_border_color',
		    	'priority'   => 30, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));


/*------------------------------------*\

	END SKIN SETTINGS

\*------------------------------------*/



/*------------------------------------*\

	LIGHT SKIN SETTINGS

\*------------------------------------*/

    //Adds a new section to the Theme Customization admin screen.
    $wp_customize->add_section( 'kbv_light_skin_section' , array(
    	'title'      => __( 'Light Text', 'Ilander' ), //The visible name of a controller section.
    	'priority'   => 158, //This controls the order in which this section appears in the Theme Customizer sidebar.
    	'description' => __('How text will appear on dark or colored backgrounds when "light text" is checked', 'Ilander'),
    ));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_light_header_color' , array(
	    	'default'     => '#fff',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_light_header_color', array(
		    	'label'        => __( 'Header Font Color', 'Ilander' ),
		    	'section'    => 'kbv_light_skin_section',
		    	'settings'   => 'kbv_light_header_color',
		    	'priority'   => 1, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_light_body_color' , array(
	    	'default'     => '#fff',
	    	'sanitize_callback' => 'kbv_sanitize_color', 
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_light_body_color', array(
		    	'label'        => __( 'Body Font Color', 'Ilander' ),
		    	'section'    => 'kbv_light_skin_section',
		    	'settings'   => 'kbv_light_body_color',
		    	'priority'   => 10, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_light_link_color' , array(
	    	'default'     => '#49ccc7',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_light_link_color', array(
		    	'label'        => __( 'Link Font Color', 'Ilander' ),
		    	'section'    => 'kbv_light_skin_section',
		    	'settings'   => 'kbv_light_link_color',
		    	'priority'   => 15, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));


/*------------------------------------*\

	END LIGHT SKIN SETTINGS

\*------------------------------------*/



/*------------------------------------*\

	HEADER SETTINGS

\*------------------------------------*/

	//Adds a new section to the Theme Customization admin screen.
	$wp_customize->add_section( 'kbv_header_section' , array(
    	'title'      => __( 'Header', 'Ilander' ), //The visible name of a controller section.
    	'priority'   => 150, //This controls the order in which this section appears in the Theme Customizer sidebar.
    ));

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting('kbv_logo_font_size', array(
		        'default' => '28',
		        'sanitize_callback' => 'kbv_sanitize_integer',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_logo_font_size', array(
			    'label'   => 'Logo Font Size',
			    'section' => 'kbv_header_section',
			    'type'    => 'select',
			    'choices'    => $kbv_font_sizes,
			    'priority'   => 5, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting( 'kbv_header_bg_color' , array(
	    	'default'     => '#fff',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_header_bg_color', array(
		    	'label'        => __( 'Background Color', 'Ilander' ),
		    	'section'    => 'kbv_header_section',
		    	'settings'   => 'kbv_header_bg_color',
		    	'priority'   => 10, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_header_social_color' , array(
	    	'default'     => '#595959',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_header_social_color', array(
		    	'label'        => __( 'Social Media Icon Color', 'Ilander' ),
		    	'section'    => 'kbv_header_section',
		    	'settings'   => 'kbv_header_social_color',
		    	'priority'   => 15, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_header_social_color_hover' , array(
	    	'default'     => '#212121',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_header_social_color_hover', array(
		    	'label'        => __( 'Social Media Icon Color On Hover', 'Ilander' ),
		    	'section'    => 'kbv_header_section',
		    	'settings'   => 'kbv_header_social_color_hover',
		    	'priority'   => 20, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

/*------------------------------------*\

	END HEADER SETTINGS

\*------------------------------------*/


/*------------------------------------*\

	NAVIGATION SETTINGS

\*------------------------------------*/

	//Adds a new section to the Theme Customization admin screen.
	$wp_customize->add_section( 'kbv_nav_section' , array(
    	'title'      => __( 'Navigation', 'Ilander' ), //The visible name of a controller section.
    	'priority'   => 151, //This controls the order in which this section appears in the Theme Customizer sidebar.
    ));

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting('kbv_nav_font', array(
		        'default' => 'Lato',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_nav_font', array(
			    'label'   => 'Navigation Font',
			    'section' => 'kbv_nav_section',
			    'type'    => 'select',
			    'choices'    => $kbv_custom_fonts,
			    'priority'   => 1, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) ); 

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_nav_font_size', array(
		        'default' => '14',
		        'sanitize_callback' => 'kbv_sanitize_integer',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_nav_font_size', array(
			    'label'   => 'Navigation Font Size',
			    'section' => 'kbv_nav_section',
			    'type'    => 'select',
			    'choices'    => $kbv_font_sizes,
			    'priority'   => 5, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_nav_color' , array(
	    	'default'     => '#a0a0a0',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_nav_color', array(
		    	'label'        => __( 'Navigation Color', 'Ilander' ),
		    	'section'    => 'kbv_nav_section',
		    	'settings'   => 'kbv_nav_color',
		    	'priority'   => 10, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_nav_hover_color' , array(
	    	'default'     => '#212121',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_nav_hover_color', array(
		    	'label'        => __( 'Navigation Hover Color', 'Ilander' ),
		    	'section'    => 'kbv_nav_section',
		    	'settings'   => 'kbv_nav_hover_color',
		    	'priority'   => 15,
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_dropdown_background_color' , array(
	    	'default'     => '#262222',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_dropdown_background_color', array(
		    	'label'        => __( 'Dropdown Background Color', 'Ilander' ),
		    	'section'    => 'kbv_nav_section',
		    	'settings'   => 'kbv_dropdown_background_color',
		    	'priority'   => 20, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_dropdown_background_hover_color' , array(
	    	'default'     => '#000',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_dropdown_background_hover_color', array(
		    	'label'        => __( 'Dropdown Background Hover Color', 'Ilander' ),
		    	'section'    => 'kbv_nav_section',
		    	'settings'   => 'kbv_dropdown_background_hover_color',
		    	'priority'   => 25, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));


/*------------------------------------*\

	END NAVIGATION SETTINGS

\*------------------------------------*/



/*------------------------------------*\

	HEADER TYPOGRAPHY SETTINGS

\*------------------------------------*/

	//Adds a new section to the Theme Customization admin screen.
	$wp_customize->add_section( 'kbv_header_typography_section' , array(
    	'title'      => __( 'Header Typography', 'Ilander' ), //The visible name of a controller section.
    	'priority'   => 153, //This controls the order in which this section appears in the Theme Customizer sidebar.
    	'description' => __('', 'Ilander'),
    ));

    //HEADER 1

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting('kbv_h1_font', array(
		        'default' => 'Lato',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h1_font', array(
			    'label'   => 'H1 Font',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_custom_fonts,
			    'priority'   => 1, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h1_font_size', array(
		        'default' => '60',
		        'sanitize_callback' => 'kbv_sanitize_integer',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h1_font_size', array(
			    'label'   => 'H1 Font Size',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_font_sizes,
			    'priority'   => 5, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h1_font_weight', array(
		        'default' => 'bold',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h1_font_weight', array(
			    'label'   => 'H1 Font Weight',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => array(
			        'normal' => 'Normal',
			        'bold' => 'Bold',
			        ),
			    'priority'   => 10, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_h1_font_color' , array(
	    	'default'     => '#212121',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_h1_font_color', array(
		    	'label'        => __( 'H1 Font Color', 'Ilander' ),
		    	'section'    => 'kbv_header_typography_section',
		    	'settings'   => 'kbv_h1_font_color',
		    	'priority'   => 15, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//HEADER 2

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting('kbv_h2_font', array(
		        'default' => 'Lato',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h2_font', array(
			    'label'   => 'H2 Font',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_custom_fonts,
			    'priority'   => 20,
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h2_font_size', array(
		        'default' => '30',
		        'sanitize_callback' => 'kbv_sanitize_integer',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h2_font_size', array(
			    'label'   => 'H2 Font Size',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_font_sizes,
			    'priority'   => 25, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h2_font_weight', array(
		        'default' => 'bold',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h2_font_weight', array(
			    'label'   => 'H2 Font Weight',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => array(
			        'normal' => 'Normal',
			        'bold' => 'Bold',
			        ),
			    'priority'   => 30, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_h2_font_color' , array(
	    	'default'     => '#3a3a3a',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_h2_font_color', array(
		    	'label'        => __( 'H2 Font Color', 'Ilander' ),
		    	'section'    => 'kbv_header_typography_section',
		    	'settings'   => 'kbv_h2_font_color',
		    	'priority'   => 35, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//HEADER 3

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting('kbv_h3_font', array(
		        'default' => 'Lato',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h3_font', array(
			    'label'   => 'H3 Font',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_custom_fonts,
			    'priority'   => 40, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h3_font_size', array(
		        'default' => '18',
		        'sanitize_callback' => 'kbv_sanitize_integer',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h3_font_size', array(
			    'label'   => 'H3 Font Size',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_font_sizes,
			    'priority'   => 45,
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h3_font_weight', array(
		        'default' => 'bold',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h3_font_weight', array(
			    'label'   => 'H3 Font Weight',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => array(
			        'normal' => 'Normal',
			        'bold' => 'Bold',
			        ),
			    'priority'   => 50, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		////Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_h3_font_color' , array(
	    	'default'     => '#3a3a3a',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_h3_font_color', array(
		    	'label'        => __( 'H3 Font Color', 'Ilander' ),
		    	'section'    => 'kbv_header_typography_section',
		    	'settings'   => 'kbv_h3_font_color',
		    	'priority'   => 55, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//HEADER 4

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting('kbv_h4_font', array(
		        'default' => 'Lato',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h4_font', array(
			    'label'   => 'H4 Font',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_custom_fonts,
			    'priority'   => 60,
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h4_font_size', array(
		        'default' => '16',
		        'sanitize_callback' => 'kbv_sanitize_integer',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h4_font_size', array(
			    'label'   => 'H4 Font Size',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_font_sizes,
			    'priority'   => 65, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h4_font_weight', array(
		        'default' => 'bold',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h4_font_weight', array(
			    'label'   => 'H4 Font Weight',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => array(
			        'normal' => 'Normal',
			        'bold' => 'Bold',
			        ),
			    'priority'   => 70, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_h4_font_color' , array(
	    	'default'     => '#3a3a3a',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_h4_font_color', array(
		    	'label'        => __( 'H4 Font Color', 'Ilander' ),
		    	'section'    => 'kbv_header_typography_section',
		    	'settings'   => 'kbv_h4_font_color',
		    	'priority'   => 75, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));
		
		//HEADER 5

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting('kbv_h5_font', array(
		        'default' => 'Lato',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h5_font', array(
			    'label'   => 'H5 Font',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_custom_fonts,
			    'priority'   => 80, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h5_font_size', array(
		        'default' => '12',
		        'sanitize_callback' => 'kbv_sanitize_integer',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h5_font_size', array(
			    'label'   => 'H5 Font Size',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_font_sizes,
			    'priority'   => 85,
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h5_font_weight', array(
		        'default' => 'bold',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h5_font_weight', array(
			    'label'   => 'H5 Font Weight',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => array(
			        'normal' => 'Normal',
			        'bold' => 'Bold',
			        ),
			    'priority'   => 90, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_h5_font_color' , array(
	    	'default'     => '#3a3a3a',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_h5_font_color', array(
		    	'label'        => __( 'H5 Font Color', 'Ilander' ),
		    	'section'    => 'kbv_header_typography_section',
		    	'settings'   => 'kbv_h5_font_color',
		    	'priority'   => 95, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//HEADER 6

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting('kbv_h6_font', array(
		        'default' => 'Lato',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h6_font', array(
			    'label'   => 'H6 Font',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_custom_fonts,
			    'priority'   => 100, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h6_font_size', array(
		        'default' => '10',
		        'sanitize_callback' => 'kbv_sanitize_integer',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h6_font_size', array(
			    'label'   => 'H6 Font Size',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_font_sizes,
			    'priority'   => 105, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_h6_font_weight', array(
		        'default' => 'bold',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_h6_font_weight', array(
			    'label'   => 'H6 Font Weight',
			    'section' => 'kbv_header_typography_section',
			    'type'    => 'select',
			    'choices'    => array(
			        'normal' => 'Normal',
			        'bold' => 'Bold',
			        ),
			    'priority'   => 110, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_h6_font_color' , array(
	    	'default'     => '#3a3a3a',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_h6_font_color', array(
		    	'label'        => __( 'H6 Font Color', 'Ilander' ),
		    	'section'    => 'kbv_header_typography_section',
		    	'settings'   => 'kbv_h6_font_color',
		    	'priority'   => 115, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

/*------------------------------------*\

	END HEADER TYPOGRAPHY SETTINGS

\*------------------------------------*/







/*------------------------------------*\

	BODY TYPOGRAPHY SETTINGS

\*------------------------------------*/

	//Adds a new section to the Theme Customization admin screen.
	$wp_customize->add_section( 'kbv_body_typography_section' , array(
    	'title'      => __( 'Body Typography', 'Ilander' ), //The visible name of a controller section.
    	'priority'   => 155, //This controls the order in which this section appears in the Theme Customizer sidebar.
    ));

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting('kbv_body_font', array(
		        'default' => 'Lato',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_body_font', array(
			    'label'   => 'Body Font',
			    'section' => 'kbv_body_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_custom_fonts,
			    'priority'   => 5, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );
		
		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_body_font_color' , array(
	    	'default'     => '#303030',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_body_font_color', array(
		    	'label'        => __( 'Body Font Color', 'Ilander' ),
		    	'section'    => 'kbv_body_typography_section',
		    	'settings'   => 'kbv_body_font_color',
		    	'priority'   => 10, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_body_font_size', array(
		        'default' => '14',
		        'sanitize_callback' => 'kbv_sanitize_integer',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_body_font_size', array(
			    'label'   => 'Body Font Size',
			    'section' => 'kbv_body_typography_section',
			    'type'    => 'select',
			    'choices'    => $kbv_font_sizes,
			    'priority'   => 15, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

/*------------------------------------*\

	END BODY TYPOGRAPHY SETTINGS

\*------------------------------------*/



/*------------------------------------*\

	FOOTER SETTINGS

\*------------------------------------*/

	//Adds a new section to the Theme Customization admin screen.
	$wp_customize->add_section( 'kbv_footer_section' , array(
    	'title'      => __( 'Footer', 'Ilander' ), //The visible name of a controller section.
    	'priority'   => 160, //This controls the order in which this section appears in the Theme Customizer sidebar.
    ));

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting('kbv_footer_widget_col_count', array(
		        'default' => 'col-4',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_footer_widget_col_count', array(
			    'label'   => 'Number Of Footer Widget Columns',
			    'section' => 'kbv_footer_section',
			    'type'    => 'select',
			    'choices'    => array(
			        'col-4' => '4 Columns',
			        'col-3' => '3 Columns',
			        'col-2' => '2 Columns',
			        'none' => 'No footer widgets',
			        ),
			    'priority'   => 3, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting( 'kbv_footer_bg_color' , array(
	    	'default'     => '#272727',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_footer_bg_color', array(
		    	'label'        => __( 'Background Color', 'Ilander' ),
		    	'section'    => 'kbv_footer_section',
		    	'settings'   => 'kbv_footer_bg_color',
		    	'priority'   => 5, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_footer_header_font_color' , array(
	    	'default'     => '#fff',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_footer_header_font_color', array(
		    	'label'        => __( 'Header Font Color', 'Ilander' ),
		    	'section'    => 'kbv_footer_section',
		    	'settings'   => 'kbv_footer_header_font_color',
		    	'priority'   => 10, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_footer_body_font_color' , array(
	    	'default'     => '#fff',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_footer_body_font_color', array(
		    	'label'        => __( 'Body Font Color', 'Ilander' ),
		    	'section'    => 'kbv_footer_section',
		    	'settings'   => 'kbv_footer_body_font_color',
		    	'priority'   => 15, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_footer_link_font_color' , array(
	    	'default'     => '#49ccc7',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_footer_link_font_color', array(
		    	'label'        => __( 'Link Font Color', 'Ilander' ),
		    	'section'    => 'kbv_footer_section',
		    	'settings'   => 'kbv_footer_link_font_color',
		    	'priority'   => 20, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_footer_copy_bg_color' , array(
	    	'default'     => '#1a1919',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_footer_copy_bg_color', array(
		    	'label'        => __( 'Footer Copyright Background Color', 'Ilander' ),
		    	'section'    => 'kbv_footer_section',
		    	'settings'   => 'kbv_footer_copy_bg_color',
		    	'priority'   => 25, //This controls the order in which this control appears in the Theme Customizer sidebar.
		  	)));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_copyright' , array(
	    	'default'     => 'Copyright Ilander',
	    	'sanitize_callback' => 'kbv_sanitize_text',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_copyright', array(
		            'label'          => __( 'Footer Copyright Text', 'Ilander' ),
		            'section'        => 'kbv_footer_section',
		            'settings'       => 'kbv_copyright',
		            'priority'   => 30, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));

/*------------------------------------*\

	END FOOTER SETTINGS

\*------------------------------------*/

/*------------------------------------*\

	PORTFOLIO SETTINGS

\*------------------------------------*/

	//Adds a new section to the Theme Customization admin screen.
	$wp_customize->add_section( 'kbv_portfolio_section' , array(
    	'title'      => __( 'Portfolio', 'Ilander' ), //The visible name of a controller section.
    	'priority'   => 170, //This controls the order in which this section appears in the Theme Customizer sidebar.
    	'description' => __('How the portfolio section will look on a categories template or on an archive template', 'Ilander'),
    ));

    	$wp_customize->add_setting( 'kbv_full_folio_width', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control(
		    'kbv_full_folio_width',
			    array(
			        'type' => 'checkbox',
			        'label' => 'Full Width',
			        'section' => 'kbv_portfolio_section',
			        'priority'   => 5,
			    )
			);

    	//Adds a new theme setting that can be customized using the Theme Customization API.
    	$wp_customize->add_setting('kbv_image_dimension', array(
		        'default' => 'normal',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_image_dimension', array(
			    'label'   => 'Image Dimension',
			    'section' => 'kbv_portfolio_section',
			    'type'    => 'select',
			    'choices'    => array(
			        'normal' => 'Normal',
			        'square' => 'Square',
			        'wide' => 'Wide',
			        'tall' => 'Tall',
			        ),
			    'priority'   => 10, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_image_size', array(
		        'default' => 'folio-col-6',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_image_size', array(
			    'label'   => 'Image Size',
			    'section' => 'kbv_portfolio_section',
			    'type'    => 'select',
			    'choices'    => array(
			        'folio-col-1' => '1 Column',
			        'folio-col-2' => '2 Columns',
			        'folio-col-3' => '3 Columns',
			        'folio-col-4' => '4 columns',
			        'folio-col-6' => '6 columns',
			        'folio-col-8' => '8 columns',
			        'folio-col-10' => '10 columns',
			        'folio-col-12' => '12 columns',
			        ),
			    'priority'   => 20, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_include_gutter', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control(
		    'kbv_include_gutter',
			    array(
			        'type' => 'checkbox',
			        'label' => 'Include Gutter',
			        'section' => 'kbv_portfolio_section',
			        'priority'   => 30, //This controls the order in which this control appears in the Theme Customizer sidebar.
			    )
			);

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_include_folio_masonry', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control(
		    'kbv_include_folio_masonry',
			    array(
			        'type' => 'checkbox',
			        'label' => 'Masonry Layout',
			        'section' => 'kbv_portfolio_section',
			        'priority'   => 40, //This controls the order in which this control appears in the Theme Customizer sidebar.
			    )
			);

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting('kbv_masonry_size', array(
		        'default' => 'normal',
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		 
			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( 'kbv_masonry_size', array(
			    'label'   => 'Masonry Image Size',
			    'section' => 'kbv_portfolio_section',
			    'type'    => 'select',
			    'choices'    => array(
			        'normal' => 'Normal',
			        'small' => 'Small',
			        ),
			    'priority'   => 50, //This controls the order in which this control appears in the Theme Customizer sidebar.
			) );

		//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_folio_facebook_share', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);

		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
	    'kbv_folio_facebook_share',
		    array(
		        'type' => 'checkbox',
		        'label' => 'Add Facebook Share Button',
		        'section' => 'kbv_portfolio_section',
		        'priority'   => 60, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_folio_twitter_share', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);

		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
	    'kbv_folio_twitter_share',
		    array(
		        'type' => 'checkbox',
		        'label' => 'Add Twitter Share Button',
		        'section' => 'kbv_portfolio_section',
		        'priority'   => 65, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_folio_google_share', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);

		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
	    'kbv_folio_google_share',
		    array(
		        'type' => 'checkbox',
		        'label' => 'Add Google Plus Share Button',
		        'section' => 'kbv_portfolio_section',
		        'priority'   => 70, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_folio_pinterest_share', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);

		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
	    'kbv_folio_pinterest_share',
		    array(
		        'type' => 'checkbox',
		        'label' => 'Add Pinterest Share Button',
		        'section' => 'kbv_portfolio_section',
		        'priority'   => 75, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

/*------------------------------------*\

	END PORTFOLIO SETTINGS

\*------------------------------------*/


/*------------------------------------*\

	BLOG SETTINGS

\*------------------------------------*/

//Adds a new section to the Theme Customization admin screen.
$wp_customize->add_section( 'kbv_blog_section' , array(
    	'title'      => __( 'Blog and Posts', 'Ilander' ), //The visible name of a controller section.
    	'priority'   => 175, //This controls the order in which this control appears in the Theme Customizer sidebar.
    	'description' => __('Choose blog settings', 'Ilander'),
    ));

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_post_content', array(
	        'default' => 'summary',
	        'sanitize_callback' => 'kbv_sanitize_text',
	    )
	);
	 
		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
		    'kbv_post_content',
		    array(
		        'type' => 'radio',
		        'label' => 'Post Content',
		        'section' => 'kbv_blog_section',
		        'choices' => array(
		            'full_text' => 'Full Text',
		            'summary' => 'Summary',
		        ),
		        'priority'   => 5,
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_full_blog_width', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);

		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
	    'kbv_full_blog_width',
		    array(
		        'type' => 'checkbox',
		        'label' => 'Full Width Blog',
		        'section' => 'kbv_blog_section',
		        'priority'   => 10, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_include_sidebar', array(
			 'default' => true,
			 'sanitize_callback' => 'kbv_sanitize_text',
		) 
	);

		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
	    'kbv_include_sidebar',
		    array(
		        'type' => 'checkbox',
		        'label' => 'Include Sidebar',
		        'section' => 'kbv_blog_section',
		        'priority'   => 15, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_post_bg_color' , array(
	    	'default'     => '#fff',
	    	'sanitize_callback' => 'kbv_sanitize_color',
	  	));

			//Displays a new controller on the Theme Customization admin screen
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kbv_post_bg_color', array(
		    	'label'        => __( 'Blog Post Background Color', 'Ilander' ),
		    	'section'    => 'kbv_blog_section',
		    	'settings'   => 'kbv_post_bg_color',
		    	'priority'   => 25,
		  	)));

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_include_masonry', array(
			 'default' => false,
			 'sanitize_callback' => 'kbv_sanitize_text',
		) 
	);

		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
	    'kbv_include_masonry',
		    array(
		        'type' => 'checkbox',
		        'label' => 'Masonry Layout',
		        'section' => 'kbv_blog_section',
		        'priority'   => 30, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_masonry_style', array(
	        'default' => 'w3',
	        'sanitize_callback' => 'kbv_sanitize_text',
	    )
	);
	 
		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
		    'kbv_masonry_style',
		    array(
		        'type' => 'radio',
		        'label' => 'Masonry Column Count',
		        'section' => 'kbv_blog_section',
		        'choices' => array(
		            'entry-span6' => '2 Column',
		            'entry-span3' => '4 Column',
		        ),
		        'priority'   => 35, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_post_facebook_share', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);

		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
	    'kbv_post_facebook_share',
		    array(
		        'type' => 'checkbox',
		        'label' => 'Add Facebook Share Button',
		        'section' => 'kbv_blog_section',
		        'priority'   => 40, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_post_twitter_share', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);
		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
	    'kbv_post_twitter_share',
		    array(
		        'type' => 'checkbox',
		        'label' => 'Add Twitter Share Button',
		        'section' => 'kbv_blog_section',
		        'priority'   => 41, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_post_google_share', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);

		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
	    'kbv_post_google_share',
		    array(
		        'type' => 'checkbox',
		        'label' => 'Add Google Plus Share Button',
		        'section' => 'kbv_blog_section',
		        'priority'   => 42, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_post_pinterest_share', array(
		        'sanitize_callback' => 'kbv_sanitize_text',
		    )
		);

		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control(
	    'kbv_post_pinterest_share',
		    array(
		        'type' => 'checkbox',
		        'label' => 'Add Pinterest Share Button',
		        'section' => 'kbv_blog_section',
		        'priority'   => 43, //This controls the order in which this control appears in the Theme Customizer sidebar.
		    )
		);

	//Adds a new theme setting that can be customized using the Theme Customization API.
	$wp_customize->add_setting( 'kbv_blog_label' , array(
    	'default'     => 'Read More',
	   	'sanitize_callback' => 'kbv_sanitize_text',
		)
	);

		//Displays a new controller on the Theme Customization admin screen
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_blog_label', array(
		        'label'          => __( 'Read More Label', 'Ilander' ),
		        'section'        => 'kbv_blog_section',
		        'settings'       => 'kbv_blog_label',
		        'priority'   => 50, //This controls the order in which this control appears in the Theme Customizer sidebar.
		        'sanitize_callback' => 'kbv_sanitize_text',
		    ))
		);




/*------------------------------------*\

	END BLOG SETTINGS

\*------------------------------------*/



/*------------------------------------*\

	SOCIAL MEDIA SETTINGS

\*------------------------------------*/

    //Adds a new section to the Theme Customization admin screen.
    $wp_customize->add_section( 'kbv_social_media_section' , array(
    	'title'      => __( 'Social Media', 'Ilander' ), //The visible name of a controller section.
    	'priority'   => 180, //This controls the order in which this section appears in the Theme Customizer sidebar.
    	'description' => __('Enter social media URL', 'Ilander'),
    ));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_facebook_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_facebook_url', array(
		            'label'          => __( 'Facebook URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_facebook_url',
		            'priority'   => 1, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_twitter_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_twitter_url', array(
		            'label'          => __( 'Twitter URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_twitter_url',
		            'priority'   => 5, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_linkedin_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_linkedin_url', array(
		            'label'          => __( 'LinkedIn URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_linkedin_url',
		            'priority'   => 10, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_youtube_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_youtube_url', array(
		            'label'          => __( 'Youtube URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_youtube_url',
		            'priority'   => 15, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_pinterest_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_pinterest_url', array(
		            'label'          => __( 'Pinterest URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_pinterest_url',
		            'priority'   => 20, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_flickr_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_flickr_url', array(
		            'label'          => __( 'Flickr URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_flickr_url',
		            'priority'   => 25,
		     )));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_google_plus_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_google_plus_url', array(
		            'label'          => __( 'Google Plus URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_google_plus_url',
		            'priority'   => 25, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_tumblr_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_tumblr_url', array(
		            'label'          => __( 'Tumblr URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_tumblr_url',
		            'priority'   => 30, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_behance_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_behance_url', array(
		            'label'          => __( 'Behance URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_behance_url',
		            'priority'   => 35,
		     )));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_instagram_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_instagram_url', array(
		            'label'          => __( 'Instagram URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_instagram_url',
		            'priority'   => 40, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_sound_cloud_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_sound_cloud_url', array(
		            'label'          => __( 'Sound Cloud URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_sound_cloud_url',
		            'priority'   => 45, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));

		//Adds a new theme setting that can be customized using the Theme Customization API.
		$wp_customize->add_setting( 'kbv_reddit_url' , array(
	    	'default'     => '',
	    	'sanitize_callback' => 'kbv_sanitize_url',
	  	));

		  	//Displays a new controller on the Theme Customization admin screen
		  	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'kbv_reddit_url', array(
		            'label'          => __( 'Reddit URL', 'Ilander' ),
		            'section'        => 'kbv_social_media_section',
		            'settings'       => 'kbv_reddit_url',
		            'priority'   => 50, //This controls the order in which this control appears in the Theme Customizer sidebar.
		     )));



/*------------------------------------*\

	END SOCIAL MEDIA SETTINGS

\*------------------------------------*/

}

add_action( 'customize_register', 'kbv_customize_options_register' );


//This is the dynamic CSS. This CSS will be output in the header.
function kbv_skin_css() { //Set each theme mod and set it as a variable.
	//General
	$kbv_section_width = get_theme_mod('kbv_section_width', 1100 );
	$kbv_logo_font_size = get_theme_mod('kbv_logo_font_size', '28' ); 
	//Main Skin Colors
	$kbv_main_color = get_theme_mod('kbv_main_color', '#212121' );
	$kbv_bg_color = get_theme_mod('kbv_bg_color', '#f8f8f8' );
	$kbv_header_bg_color = get_theme_mod('kbv_header_bg_color', '#fff' );
	$kbv_accent_color_one = get_theme_mod('kbv_accent1_color', '#49ccc7' );
	$kbv_accent_color_two = get_theme_mod('kbv_accent2_color', '#ff6e30' );
	$kbv_accent_color_three= get_theme_mod('kbv_accent3_color', '#ffc231' );
	$kbv_accent_color_four = get_theme_mod('kbv_accent4_color', '#6dd6b6' );
	$kbv_border_color = get_theme_mod('kbv_border_color', '#dfdfdf' );
	//Header
	$kbv_header_social_color = get_theme_mod('kbv_header_social_color', '#595959' );
	$kbv_header_social_color_hover = get_theme_mod('kbv_header_social_color_hover', '#212121' );
	//Body Font Typeography
	$kbv_body_font = str_replace('+', ' ', get_theme_mod('kbv_body_font', 'Lato' )); // remove "+" from google font name
	$kbv_body_font_color = get_theme_mod('kbv_body_font_color', '#303030' );
	$kbv_body_font_size = get_theme_mod('kbv_body_font_size', '14' );
	//Navigation
	$kbv_nav_font = str_replace('+', ' ', get_theme_mod('kbv_nav_font', 'Lato' )); // remove "+" from google font name
	$kbv_nav_font_size = get_theme_mod('kbv_nav_font_size', '14' );
	$kbv_nav_color = get_theme_mod('kbv_nav_color', '#a0a0a0' );
	$kbv_nav_hover_color = get_theme_mod('kbv_nav_hover_color', '#212121' );
	$kbv_dropdown_background_color = get_theme_mod('kbv_dropdown_background_color', '#262222' );
	$kbv_dropdown_background_hover_color = get_theme_mod('kbv_dropdown_background_hover_color', '#000' );
	//Posts
	$kbv_post_bg_color = get_theme_mod('kbv_post_bg_color', '#fff' );
	//h1 
	$kbv_h_one_font_color = get_theme_mod('kbv_h1_font_color', '#212121' );
	$kbv_h_one_font = str_replace('+', ' ', get_theme_mod('kbv_h1_font', 'Lato' )); // remove "+" from google font name
	$kbv_h_one_font_size = get_theme_mod('kbv_h1_font_size', '60' );
	$kbv_h_one_font_weight = get_theme_mod('kbv_h1_font_weight', 'bold' );
	//h2 
	$kbv_h_two_font_color = get_theme_mod('kbv_h2_font_color', '#3a3a3a' );
	$kbv_h_two_font = str_replace('+', ' ', get_theme_mod('kbv_h2_font', 'Lato' )); // remove "+" from google font name
	$kbv_h_two_font_size = get_theme_mod('kbv_h2_font_size', '30' );
	$kbv_h_two_font_weight = get_theme_mod('kbv_h2_font_weight', 'bold' );
	//h3 
	$kbv_h_three_font_color = get_theme_mod('kbv_h3_font_color', '#3a3a3a' );
	$kbv_h_three_font = str_replace('+', ' ', get_theme_mod('kbv_h3_font', 'Lato' )); // remove "+" from google font name
	$kbv_h_three_font_size = get_theme_mod('kbv_h3_font_size', '18' );
	$kbv_h_three_font_weight = get_theme_mod('kbv_h3_font_weight', 'bold' );
	//h4 
	$kbv_h_four_font_color = get_theme_mod('kbv_h4_font_color', '#3a3a3a' );
	$kbv_h_four_font = str_replace('+', ' ', get_theme_mod('kbv_h4_font', 'Lato' )); // remove "+" from google font name
	$kbv_h_four_font_size = get_theme_mod('kbv_h4_font_size', '16' );
	$kbv_h_four_font_weight = get_theme_mod('kbv_h4_font_weight', 'bold' );
	//h5 
	$kbv_h_five_font_color = get_theme_mod('kbv_h5_font_color', '#3a3a3a' );
	$kbv_h_five_font = str_replace('+', ' ', get_theme_mod('kbv_h5_font', 'Lato' )); // remove "+" from google font name
	$kbv_h_five_font_size = get_theme_mod('kbv_h5_font_size', '12' );
	$kbv_h_five_font_weight = get_theme_mod('kbv_h5_font_weight', 'bold' );
	//h6 
	$kbv_h_six_font_color = get_theme_mod('kbv_h6_font_color', '#3a3a3a' );
	$kbv_h_six_font = str_replace('+', ' ', get_theme_mod('kbv_h6_font', 'Lato' )); // remove "+" from google font name
	$kbv_h_six_font_size = get_theme_mod('kbv_h6_font_size', '10' );
	$kbv_h_six_font_weight = get_theme_mod('kbv_h6_font_weight', 'bold' );
	//Light Text
	$kbv_light_body_color = get_theme_mod('kbv_light_body_color', '#fff' );
	$kbv_light_link_color = get_theme_mod('kbv_light_link_color', '#49ccc7' );
	$kbv_light_header_color = get_theme_mod('kbv_light_header_color', '#fff' );
	//Footer
	$kbv_footer_copy_bg_color = get_theme_mod('kbv_footer_copy_bg_color', '#1a1919' );
	$kbv_footer_link_font_color = get_theme_mod('kbv_footer_link_font_color', '#49ccc7' );
	$kbv_footer_body_font_color = get_theme_mod('kbv_footer_body_font_color', '#fff' );
	$kbv_footer_bg_color = get_theme_mod('kbv_footer_bg_color', '#272727' );
	$kbv_footer_body_font_color = get_theme_mod('kbv_footer_body_font_color', '#fff' );
	$kbv_footer_header_font_color = get_theme_mod('kbv_footer_header_font_color', '#fff' );

	?>

	<?php
	global $post;
	  if( function_exists('has_shortcode') )
	  {
	  	//See if Visual Composer is installed
	    if( isset($post->post_content) AND !has_shortcode( $post->post_content, 'vc_row')) { 
	    	$kbv_section_default_width = ($kbv_section_width-20).'px'; //Subtract 20 from the Section Width
	    	$kbv_section_default_margin = 'auto'; //Center main body content
	    	$kbv_section_default_padding = '0 50px'; // Add this padding the main bvody content
		}
		else {
			$kbv_section_default_width = '100%'; //Set the default width to 100%;
			$kbv_section_default_margin = '0'; //Give the main body content a 0 value for the margin
	    	$kbv_section_default_padding = '0'; //Give the main body content a 0 value for the padding
		}
	  }
	?>

         <style type="text/css">
        /*--------------------------------------------------------------
		TABLE OF CONTENTS
		----------------------------------------------------------------
		1.0 - Typography
		2.0 - Elements
		3.0 - Forms
			3.1 - General
			3.2 - Search
		4.0 - Header
			4.1 - General
			4.2 - Logo
			4.3 - Social Media
		5.0 - Navigation
			5.1 - Links
			5.2 - Desktop Navigation
			5.3 - Mobile Navigation
			5.4 - Scroll Top
		6.0 - Widgets
		7.0 - Content
			7.1 - Posts
			7.2 - Pages
			7.3 - Comments
		8.0 - Media
			8.1 - Galleries
			8.2 - Video
			8.3 - Audio
		9.0 - Testimonial Slider
		10.0 - Thumbnail Gallery
		11.0 - Footer
		12.0 - Pricing Table

		--------------------------------------------------------------*/
	
			/*--------------------------------------------------------------
			1.0 Typography
			--------------------------------------------------------------*/
			html, body {
				font-family: <?php echo $kbv_body_font; ?>, sans-serif;
			}

			h1, h1 a {
				color: <?php echo $kbv_h_one_font_color; ?>;
				font-family: <?php echo $kbv_h_one_font; ?>, sans-serif;
				font-size: <?php echo $kbv_h_one_font_size; ?>px;
				font-weight: <?php echo $kbv_h_one_font_weight; ?>;
			}

			h2, h2 a {
				color: <?php echo $kbv_h_two_font_color; ?>;
				font-family: <?php echo $kbv_h_two_font; ?>, sans-serif;
				font-size: <?php echo $kbv_h_two_font_size; ?>px;
				font-weight: <?php echo $kbv_h_two_font_weight; ?>;
			}

			h3, h3 a {
				color: <?php echo $kbv_h_three_font_color; ?>;
				font-family: <?php echo $kbv_h_three_font; ?>, sans-serif;
				font-size: <?php echo $kbv_h_three_font_size; ?>px;
				font-weight: <?php echo $kbv_h_three_font_weight; ?>;
			}

			h4, h4 a {
				color: <?php echo $kbv_h_four_font_color; ?>;
				font-family: <?php echo $kbv_h_four_font; ?>, sans-serif;
				font-size: <?php echo $kbv_h_four_font_size; ?>px;
				font-weight: <?php echo $kbv_h_four_font_weight; ?>;
			}

			h5, h5 a {
				color: <?php echo $kbv_h_five_font_color; ?>;
				font-family: <?php echo $kbv_h_five_font; ?>, sans-serif;
				font-size: <?php echo $kbv_h_five_font_size; ?>px;
				font-weight: <?php echo $kbv_h_five_font_weight; ?>;
			}

			h6, h6 a {
				color: <?php echo $kbv_h_six_font_color; ?>;
				font-family: <?php echo $kbv_h_six_font; ?>, sans-serif;
				font-size: <?php echo $kbv_h_six_font_size; ?>px;
				font-weight: <?php echo $kbv_h_six_font_weight; ?>;
			}

			.light-txt {
				color: <?php echo $kbv_light_body_color; ?>;
			}

			.light-txt h1, .light-txt h2, .light-txt h3, .light-txt h4, .light-txt h5, .light-txt h6 {
				color: <?php echo $kbv_light_header_color; ?>;
			}
			/*--------------------------------------------------------------
			2.0 Elements
			--------------------------------------------------------------*/
			html, body, .vcenter {
         		color: <?php echo $kbv_body_font_color; ?>;
         		font-size: <?php echo $kbv_body_font_size; ?>px;
         	}

         	hr {
				border-top: 1px solid <?php echo $kbv_border_color; ?>;
			}

			blockquote {
				border-left:5px solid <?php echo $kbv_accent_color_one; ?>;
			}
			/*--------------------------------------------------------------
			3.0 Forms
			--------------------------------------------------------------*/
			/*--------------------------------------------------------------
			3.1 General
			--------------------------------------------------------------*/
			textarea, input {
				border: 1px solid <?php echo $kbv_border_color; ?>; 
			}
			/*--------------------------------------------------------------
			3.2 Search
			--------------------------------------------------------------*/
			.search-wrapper {
				border: 1px solid <?php echo $kbv_border_color; ?>;
				font-family: <?php echo $kbv_nav_font; ?>, sans-serif; 
			}

			/* Search */
			.search-wrapper {
				font-size: <?php echo $kbv_nav_font_size; ?>px;
			}

			input.search-text-input {
				padding: 5px <?php echo $kbv_nav_font_size + 15; ?>px 5px 5px;
			}

			.search-btn-wrapper i {
				color: <?php echo $kbv_border_color; ?>;
			}
			/*--------------------------------------------------------------
			4.0 Header
			--------------------------------------------------------------*/
			/*--------------------------------------------------------------
			4.1 General
			--------------------------------------------------------------*/
			#header {
				background: <?php echo $kbv_header_bg_color; ?>;
				border-top: solid 4px <?php echo $kbv_main_color; ?>; 
			}
			/*--------------------------------------------------------------
			4.2 Logo
			--------------------------------------------------------------*/
			#logo {
				font-size: <?php echo $kbv_logo_font_size; ?>px;
			}
			/*--------------------------------------------------------------
			4.3 Social Media
			--------------------------------------------------------------*/
			header .icon-container .icon i {
				color: <?php echo $kbv_header_social_color; ?>;
			}

			header .icon-container .icon i:hover {
				color: <?php echo $kbv_header_social_color_hover; ?>;
			}
			/*--------------------------------------------------------------
			5.0 Navigation
			--------------------------------------------------------------*/
			/*--------------------------------------------------------------
			5.1 Links
			--------------------------------------------------------------*/
			a {
				color: <?php echo $kbv_accent_color_one; ?>;
			}

			a:hover {
				color: <?php echo $kbv_body_font_color; ?>;
			}

			.light-txt a {
				color: <?php echo $kbv_light_link_color; ?>;
			}

			.light-txt a:hover {
				color: <?php echo $kbv_light_body_color; ?>;
			}

			.ui-state-default a {
         		color: <?php echo $kbv_body_font_color; ?>;
         	}

         	button {
				background: <?php echo $kbv_main_color; ?>;
			}

			.button-style-one, input.button-style-one, input[type="submit"] {
				background: <?php echo $kbv_main_color; ?>;
			}

			.button-style-two {
				border: 2px solid <?php echo $kbv_main_color; ?>;
				color: <?php echo $kbv_main_color; ?>;
			}

			.nav-post a {
				background-color: <?php echo $kbv_main_color; ?>;
			}

			#go-top {
				background: <?php echo $kbv_main_color; ?>;
			}

			.post-link a, .post-link a:hover {
				background-color: <?php echo $kbv_main_color; ?>;
			}

			.post-link-wrapper .social-share, .post-link span.close, .portfolio-slide-out-wrapper .open {
				background-color: <?php echo $kbv_main_color; ?>;
			}

			.post-link-wrapper .social-share:hover, .post-link span.close:hover, .portfolio-slide-out-wrapper .open:hover {
				background-color: <?php echo $kbv_accent_color_one; ?>;
			}

			/*--------------------------------------------------------------
			5.2 Desktop Navigation
			--------------------------------------------------------------*/
			#main-nav-container {
				font-family: <?php echo $kbv_nav_font; ?>, sans-serif;
			}
			#main-nav-container, #mobile-nav-container, .search-wrapper * {
				font-size: <?php echo $kbv_nav_font_size; ?>px ;
			}

			#main-menu > ul a{
				color: <?php echo $kbv_nav_color; ?>;
			}

			#main-menu > ul a:hover,
			#main-menu > ul > .current-menu-ancestor > a,
			#main-menu > ul > .current-menu-item > a,
			#main-menu > ul > .current-menu-parent > a {
				color: <?php echo $kbv_nav_hover_color; ?>;
			}
			/* Second level Nav */

			#main-menu > ul > li > ul:after { 
				border-left:10px solid <?php echo $kbv_dropdown_background_color; ?>; 
			}

			#main-menu > ul li:hover ul a{ 
				background: <?php echo $kbv_dropdown_background_color; ?>; 
			}

			#main-menu > ul > li > ul > li:hover > a {
				background: <?php echo $kbv_dropdown_background_hover_color; ?>;
			}

			/* Third level Nav */

			#main-menu > ul ul ul:after {
				border-right:15px solid <?php echo $kbv_dropdown_background_color; ?>; 
			}

			#main-menu > ul li:hover ul ul a{ /* The persistent hover state does however create a global style for links even before they're hovered. Here we undo these effects. */
				background: <?php echo $kbv_dropdown_background_color; ?>; 
			}

			#main-menu > ul li:hover ul ul li a:hover { /* Here we define the most explicit hover states--what happens when you hover each individual link. */
				background: <?php echo $kbv_dropdown_background_hover_color; ?>;
			}
			/*--------------------------------------------------------------
			5.3 Mobile Navigation
			--------------------------------------------------------------*/
			/* First level Nav */
			#mobile-nav-container {
				font-family: <?php echo $kbv_nav_font; ?>, sans-serif;
			}
			.navbar-toggle:hover {
				background-color: <?php echo $kbv_main_color; ?> !important;
			}

			#mobile-menu ul li {
				border-top: 1px solid <?php echo $kbv_border_color; ?>;
			}

			#mobile-menu a {
				color: <?php echo $kbv_nav_color; ?>;
			}

			#mobile-menu ul a:hover, .current_page_item > a, .current-menu-item > a, .current_page_ancestor > a {
				color: <?php echo $kbv_nav_hover_color; ?>;
			}

			#mobile-toggle {
				border: 1px solid <?php echo $kbv_border_color; ?>;
			}

			#mobile-toggle:hover {
				border: 1px solid <?php echo $kbv_main_color; ?>;
				background-color: <?php echo $kbv_main_color; ?>;
			}

			#mobile-toggle i {
				color: <?php echo $kbv_border_color; ?>;
			}
			/*--------------------------------------------------------------
			5.4 Scroll Top
			--------------------------------------------------------------*/
			#go-top {
				background: <?php echo $kbv_main_color; ?>;
			}
			/*--------------------------------------------------------------
			6.0 Widgets
			--------------------------------------------------------------*/
			.tagcloud a {
				border: 1px solid <?php echo $kbv_accent_color_one; ?>;
			}

			.tagcloud a:hover {
				background-color: <?php echo $kbv_accent_color_one; ?>;
			}

			#wrapper .widget {
				border-top:solid 4px <?php echo $kbv_main_color; ?>;
			}
			/*--------------------------------------------------------------
			7.0 Content
			--------------------------------------------------------------*/
			/*--------------------------------------------------------------
			7.1 Posts
			--------------------------------------------------------------*/
			.entry-post {
				background: <?php echo $kbv_post_bg_color; ?>;
			}

			.tags a {
				border: 1px solid <?php echo $kbv_accent_color_one; ?>;
			}

			.tags a:hover {
				border: 1px solid <?php echo $kbv_main_color; ?>;
			}
			/*--------------------------------------------------------------
			7.2 Pages
			--------------------------------------------------------------*/
			body {
         		background-color: <?php echo $kbv_footer_copy_bg_color; ?>;
         	}

         	#main-content {
         		max-width: <?php echo $kbv_section_default_width; ?>;
         		margin: <?php echo $kbv_section_default_margin; ?>;
         		padding: <?php echo $kbv_section_default_padding; ?>;
         	}

            .container {
				max-width: <?php echo $kbv_section_width; ?>px;
			}

			#wrapper {
				background: <?php echo $kbv_bg_color; ?>;
			}
			/*--------------------------------------------------------------
			7.3 Comments
			--------------------------------------------------------------*/
			.comment {
				border-top: 1px solid <?php echo $kbv_border_color; ?>;
			}
			.comment-reply-link {
				border: 2px solid <?php echo $kbv_main_color; ?>;
				color: <?php echo $kbv_main_color; ?>;
			}
			/*--------------------------------------------------------------
			8.0 Media
			--------------------------------------------------------------*/
			/*--------------------------------------------------------------
			8.1 Galleries
			--------------------------------------------------------------*/
			.flexslider .flex-direction-nav a {
				background-color: <?php echo $kbv_main_color; ?>;
			}
			/*--------------------------------------------------------------
			8.2 Video
			--------------------------------------------------------------*/
			.mejs-controls .mejs-time-rail .mejs-time-current {
				background: <?php echo $kbv_accent_color_one; ?> !important;
			}
			/*--------------------------------------------------------------
			8.3 Audio
			--------------------------------------------------------------*/
			.mejs-controls .mejs-horizontal-volume-slider .mejs-horizontal-volume-current {
				background: <?php echo $kbv_accent_color_one; ?> !important;
			}
			/*--------------------------------------------------------------
			9.0 Testimonial Slider
			--------------------------------------------------------------*/
			.quote-box-left, .quote-box {
				background-color: <?php echo $kbv_accent_color_one; ?>;
			}
			.left-triangle:after {
				border-right:30px solid <?php echo $kbv_accent_color_one; ?>;
			}

			.feat-quote {
				background-color: <?php echo $kbv_accent_color_one; ?>;
			}

			.feat-quote a {
				color: <?php echo $kbv_light_body_color; ?> !important;
			}
			/*--------------------------------------------------------------
			10.0 Thumbnail Gallery
			--------------------------------------------------------------*/
			.item .item-cover {
				background-color: <?php echo $kbv_main_color; ?>;
			}

			.item .main-color {
				background-color: <?php echo $kbv_main_color; ?>;
			}

			.item .accent-color-1 {
				background-color: <?php echo $kbv_accent_color_one; ?>;
			}

			.item .accent-color-2 {
				background-color: <?php echo $kbv_accent_color_two; ?>;
			}

			.item .accent-color-3 {
				background-color: <?php echo $kbv_accent_color_three; ?>;
			}

			.item .accent-color-4 {
				background-color: <?php echo $kbv_accent_color_four; ?>;
			}

			.portfolio-filter ul li .current {
				color: <?php echo $kbv_body_font_color; ?>;
			}
			/*--------------------------------------------------------------
			11.0 Footer
			--------------------------------------------------------------*/
			#footer {
				background-color: <?php echo $kbv_footer_bg_color; ?>;
				color: <?php echo $kbv_footer_body_font_color; ?>;
			}

			#footer h1, #footer h2, #footer h3, #footer h4, #footer h5, #footer h6 {
				color: <?php echo $kbv_footer_header_font_color; ?>;
			}

			#footer a {
				color: <?php echo $kbv_footer_link_font_color; ?>;
			}

			#footer a:hover {
				color: <?php echo $kbv_footer_body_font_color; ?>;
			}

			#footer-rights-container {
				background-color: <?php echo $kbv_footer_copy_bg_color; ?>;
			}
			/*--------------------------------------------------------------
			11.0 Pricing Table
			--------------------------------------------------------------*/
			.pricing-plan.featured .pricing {
				background: <?php echo $kbv_main_color; ?>;
			}
         </style>

    <?php
}
add_action( 'wp_head', 'kbv_skin_css');//Put CSS in the Header
add_editor_style( get_stylesheet_uri() );
?>